TINY_AUTOENCODER_FILES_SD = {
    "madebyollin/taesd": [
        "config.json",
        "diffusion_pytorch_model.safetensors",
        "taesd_decoder.safetensors",
        "taesd_encoder.safetensors",
    ]
}

TINY_AUTOENCODER_FILES_SDXL = {
    "madebyollin/sdxl-vae-fp16-fix": [
        "config.json",
        "diffusion_pytorch_model.safetensors",
        "sdxl.vae.safetensors"
    ]
}
