LLM_FILE_BOOTSTRAP_DATA = {
    "w4ffl35/Ministral-8B-Instruct-2410-doublequant": {
        "path_settings": "llm_causallm_model_path",
        "files": [
            "config.json",
            "generation_config.json",
            "model-00001-of-00002.safetensors",
            "model-00002-of-00002.safetensors",
            "model.safetensors.index.json",
            "params.json",
            "special_tokens_map.json",
            "tekken.json",
            "tokenizer.json",
            "tokenizer_config.json",
        ]
    },
    "sentence-transformers/sentence-t5-large": {
        "path_settings": "sentence_transformers_path",
        "files": [
            "1_Pooling/config.json",
            "2_Dense/config.json",
            "2_Dense/pytorch_model.bin",
            "config.json",
            "config_sentence_transformers.json",
            "model.safetensors",
            "modules.json",
            "sentence_bert_config.json",
            "special_tokens_map.json",
            "tokenizer.json",
            "tokenizer_config.json",
        ]
    },
    "meta-llama/Meta-Llama-3-8B-Instruct": {
        "path_settings": "llm_causallm_model_path",
        "files": [
            "config.json",
            "generation_config.json",
            "model-00001-of-00004.safetensors",
            "model-00002-of-00004.safetensors",
            "model-00003-of-00004.safetensors",
            "model-00004-of-00004.safetensors",
            "model.safetensors.index.json",
            "special_tokens_map.json",
            "tokenizer.json",
            "tokenizer_config.json",
        ]
    },
    "intfloat/e5-large": {
        "path_settings": "text_embedding",
        "files": [
            "1_Pooling/config.json",
            "config.json",
            "model.safetensors",
            "modules.json",
            "sentence_bert_config.json",
            "special_tokens_map.json",
            "tokenizer.json",
            "tokenizer_config.json",
            "vocab.txt"
        ]
    },
}
